;; Generated package description from doric-themes.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "doric-themes" "0.0.1" "Minimalist themes" '((emacs "29.1")) :commit "858412fd694cb769fb427e3323d2e1344ff10d98" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("faces" "theme" "accessibility") :url "https://github.com/protesilaos/doric-themes")
